@@ -14,10 +14,11 @@
 import logging
 
 from boto3.session import Session
+from boto3.compat import _warn_deprecated_python
 
 
 __author__ = 'Amazon Web Services'
-__version__ = '1.16.2'
+__version__ = '1.16.13'
 
 
 # The default Boto3 session; autoloaded when needed.
@@ -78,6 +79,7 @@ def _get_default_session():
     """
     if DEFAULT_SESSION is None:
         setup_default_session()
+    _warn_deprecated_python()
 
     return DEFAULT_SESSION
 
